// Fig 18.5: FileTestForm.cs
// Using classes File and Directory.
using System;
using System.Windows.Forms;
using System.IO;

// displays contents of files and directories
public partial class FileTestForm : Form
{
   // parameterless constructor
   public FileTestForm()
   {
      InitializeComponent();
   } // end constructor

   // invoked when user presses key
   private void inputTextBox_KeyDown( object sender, KeyEventArgs e )
   {
      // determine whether user pressed Enter key
      if ( e.KeyCode == Keys.Enter )
      {
         string fileName; // name of file or directory

         // get user-specified file or directory
         fileName = inputTextBox.Text;

         // determine whether fileName is a file
         if ( File.Exists( fileName ) )
         {
            // get file's creation date, 
            // modification date, etc.
            outputTextBox.Text = GetInformation( fileName );

            // display file contents through StreamReader
            try
            {
               // obtain reader and file contents
               StreamReader stream = new StreamReader( fileName );
               outputTextBox.Text += stream.ReadToEnd();
            } // end try
            // handle exception if StreamReader is unavailable
            catch ( IOException )
            {
               MessageBox.Show( "Error reading from file", "File Error",
                  MessageBoxButtons.OK, MessageBoxIcon.Error );
            } // end catch
         } // end if
         // determine whether fileName is a directory
         else if ( Directory.Exists( fileName ) )
         {
            string[] directoryList;  // array for directories

            // get directory's creation date, 
            // modification date, etc.
            outputTextBox.Text = GetInformation( fileName );

            // obtain file/directory list of specified directory
            directoryList = Directory.GetDirectories( fileName );

            outputTextBox.Text += "\r\n\r\nDirectory contents:\r\n";

            // output directoryList contents
            for ( int i = 0; i < directoryList.Length; i++ )
               outputTextBox.Text += directoryList[ i ] + "\r\n";
         } // end else if
         else
         {
            // notify user that neither file nor directory exists
            MessageBox.Show( inputTextBox.Text +
               " does not exist", "File Error",
               MessageBoxButtons.OK, MessageBoxIcon.Error );
         } // end else
      } // end if
   } // end method inputTextBox_KeyDown

   // get information on file or directory
   private string GetInformation( string fileName )
   {
      string information;

      // output that file or directory exists
      information = fileName + " exists\r\n\r\n";

      // output when file or directory was created
      information += "Created: " +
         File.GetCreationTime( fileName ) + "\r\n";

      // output when file or directory was last modified
      information += "Last modified: " +
         File.GetLastWriteTime( fileName ) + "\r\n";

      // output when file or directory was last accessed
      information += "Last accessed: " +
         File.GetLastAccessTime( fileName ) + "\r\n" + "\r\n";

      return information;
   } // end method GetInformation
} // end class FileTestForm



/**************************************************************************
 * (C) Copyright 1992-2006 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/